@@ -5,19 +5,20 @@ from .futures import Future, WrappingFuture, InvalidStateError, FutureCollection
 from .id_allocator import IDAllocator, SequentialIssuer
 from .locked_dataset import LockedDataset
 from .locked_structure import LockedStructure
-from .monitor import MonitorList, Monitor, MonitorDict, RMonitor
+from .monitor import MonitorList, Monitor, MonitorDict, RMonitor, MonitorSet
 from .sync import sync_threadpool
 from .thread import TerminableThread, Condition, SingleStartThread, call_in_separate_thread, \
     BogusTerminableThread, IntervalTerminableThread
 from .timer import Timer
 from .thread_collection import ThreadCollection
 from .queue import PeekableQueue
+from .list_processor import parallel_construct
 
 __all__ = ['LockedDataset', 'Monitor', 'RMonitor', 'CallableGroup', 'TerminableThread',
            'MonitorDict', 'MonitorList', 'Condition', 'LockedStructure', 'AtomicNumber',
            'CallNoOftenThan', 'SingleStartThread', 'IDAllocator', 'call_in_separate_thread',
            'BogusTerminableThread', 'Timer', 'parallel_execute', 'run_as_future',
-           'sync_threadpool', 'IntervalTerminableThread', 'Future',
-           'WrappingFuture', 'InvalidStateError', 'PeekableQueue',
+           'sync_threadpool', 'IntervalTerminableThread', 'Future', 'MonitorSet',
+           'WrappingFuture', 'InvalidStateError', 'PeekableQueue', 'parallel_construct',
            'CancellableCallback', 'ThreadCollection', 'FutureCollection',
            'SequentialIssuer']
