@@ -5,6 +5,7 @@ from inspect import Parameter, signature
 from queue import Queue
 
 from satella.coding.recast_exceptions import rethrow_as
+from queue import Empty
 
 
 def enum_value(value):
@@ -59,9 +60,14 @@ class Closeable:
 
     Can be also used as a context manager, with close() called upon __exit__.
 
-    You should extend both __init__ and close()
+    .. warning:: You should extend both __init__ and close(). Invoke __init__() at the end of
+        your class constructor, this will prevent the destructor from closing on half-initialized
+        classes.
+
+    Objects before initialization (calling of this constructor) are considered closed.
+    Checking if they are closed will emit a warning.
     """
-    __slots__ = ('__finalized', )
+    __slots__ = '__finalized',
 
     def __init__(self):
         self.__finalized = False
@@ -71,7 +77,12 @@ class Closeable:
         """
         :return: whether this object is closed
         """
-        return self.__finalized
+        try:
+            return self.__finalized
+        except AttributeError:
+            warnings.warn('You are checking whether a non-initialized object was closed',
+                          UserWarning)
+            return True
 
     def close(self) -> bool:
         """
@@ -90,7 +101,7 @@ class Closeable:
         try:
             return not self.__finalized
         except AttributeError:
-            raise RuntimeError('__finalized not found, did you forget to call the constructor?')
+            warnings.warn('Attempted to clean up a non-initialized object', UserWarning)
         finally:
             self.__finalized = True
 
@@ -112,7 +123,10 @@ def queue_iterator(queue: Queue) -> tp.Iterator:
     >>>     yield queue.get()
     """
     while queue.qsize() > 0:
-        yield queue.get()
+        try:
+            yield queue.get(block=False)
+        except Empty:
+            return
 
 
 def update_if_not_none(dictionary: tp.Dict, key: tp.Hashable, value) -> tp.Dict:
@@ -135,6 +149,7 @@ def chain_callables(callable1: tp.Callable, callable2: tp.Callable) -> tp.Callab
     :param callable2: callable to call with callable1's result
     :return: result of callable2
     """
+
     def inner(*args, **kwargs):
         res = callable1(*args, **kwargs)
         try:
@@ -146,6 +161,7 @@ def chain_callables(callable1: tp.Callable, callable2: tp.Callable) -> tp.Callab
             else:
                 raise
         return res
+
     return inner
 
 
@@ -305,7 +321,7 @@ def _get_arguments(function: tp.Callable, special_behaviour: bool, *args, **kwar
                     else:
                         v = keyword.default
                 except (AttributeError, TypeError):
-                    continue    # comparison was impossible
+                    continue  # comparison was impossible
 
             local_vars[keyword_name] = v
 
