@@ -3,8 +3,7 @@ from abc import ABCMeta, abstractmethod
 
 __all__ = ['Iteratable', 'T', 'U', 'V', 'K', 'Number', 'ExceptionClassType',
            'NoArgCallable', 'Appendable', 'Predicate', 'KVTuple',
-           'Comparable', 'ExceptionList']
-
+           'Comparable', 'ExceptionList', 'NoneType']
 
 NoneType = None.__class__
 T = tp.TypeVar('T')
@@ -46,5 +45,3 @@ except ImportError:
 class Appendable(Protocol[T]):
     def append(self, item: T) -> None:
         ...
-
-
